@@ -2,5 +2,5 @@
 # E-mail: hehy@lamda.nju.edu.cn
 # All rights reserved.
 name = "recorder"
-import recorder.recorder as recorder
+from recorder.recorder import *
 
